# 窗体控件库主题风格使用说明
## 1. 引用 Kintai.Windows 命名空间；
## 2. 所有窗体（Form）继承改为：ThemeForm
## 3. 所有用户控件（UserControl）继承改为：ThemeUserControl 
## 4. 所有消息框（MessageBox.Show）改为：this.ShowMsg
## 5. 设置主题
      Theme.CurrentTheme = new Themes.Dark();//设置主题 深色
      或者
      Theme.CurrentTheme = new Themes.Light();//设置主题 浅色
##（以下设置位置任选其一）  
### 5.1. 程序启动时 
Program.cs 调用方法示例：    
```
static class Program
{
    /// <summary>
    ///  The main entry point for the application.
    /// </summary>
    [STAThread]
    static void Main()
    {
        Application.SetHighDpiMode(HighDpiMode.SystemAware);
        Application.EnableVisualStyles();
        Application.SetCompatibleTextRenderingDefault(false);
        Theme.CurrentTheme = new Themes.Dark();//设置主题 深色
        Application.Run(new FrmTheme());
    }
}
```
### 5.2. 窗体加载时   
Form_Load 调用方法示例： 
``` 
public partial class FrmTheme : ThemeForm
{
    public FrmTheme()
    {
        InitializeComponent();
    }

    private void ThemeForm_Load(object sender, EventArgs e)
    {
        ThisTheme = new Themes.Dark();//设置主题 深色
        // 示例带主题风格的消息框
        var res = this.ShowMsg("当前是深色主题模式", "警告", MessageBoxButtons.YesNoCancel, MessageBoxIcon.Exclamation);
        this.Text = res.ToString();
    }
}
```
### 5.3. 按钮点击时   
Button_Click 调用方法示例：   
```
private void button1_Click(object sender, EventArgs e)
{
    Theme.CurrentTheme = new Themes.Light();//设置主题 浅色
    // 示例带主题风格的消息框
    var res = this.ShowMsg("当前是浅色主题模式", "提示", MessageBoxButtons.OK, MessageBoxIcon.Information);
    this.Text = res.ToString();
}
```
## 6. 如果需要主题可配置化，只需要在程序运行目录放置theme.json文件，则其中设置就会自动加载。
theme.json示例：
```
{
"ButtonBorderSize": 3,
"FormBackColor": {"A": 255,"R": 35,"G": 45,"B": 65}//注意：DataGridView控件BackgroundColor和BackColor不支持透明的背景色，会自动将A值设为255。
}
```
## 7. 如果需要设置字体大小，只需要调用窗体或控件的设置字体接口SetFont，则其字体就会自动调整。
SetFont示例：
```
this.SetFont(new Font("黑体", 9f));
```
